==> camel-k-model-v1-6.2.0-sources.jar: io/fabric8/camelk/v1/IntegrationPlatformKameletRepositorySpecFluentImpl.java <==
package io.fabric8.camelk.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class IntegrationPlatformKameletRepositorySpecFluentImpl<A extends IntegrationPlatformKameletRepositorySpecFluent<A>> extends BaseFluent<A> implements IntegrationPlatformKameletRepositorySpecFluent<A>{
  public IntegrationPlatformKameletRepositorySpecFluentImpl() {
  }
  public IntegrationPlatformKameletRepositorySpecFluentImpl(IntegrationPlatformKameletRepositorySpec instance) {
    this.withUri(instance.getUri()); 
  }
  private String uri;
  public String getUri() {
    return this.uri;
  }
  public A withUri(String uri) {
    this.uri=uri; return (A) this;
  }
  public Boolean hasUri() {
    return this.uri != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    IntegrationPlatformKameletRepositorySpecFluentImpl that = (IntegrationPlatformKameletRepositorySpecFluentImpl) o;
    if (uri != null ? !uri.equals(that.uri) :that.uri != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(uri,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (uri != null) { sb.append("uri:"); sb.append(uri); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> camel-k-model-v1-6.7.2-sources.jar: io/fabric8/camelk/v1/IntegrationPlatformKameletRepositorySpecFluentImpl.java <==
package io.fabric8.camelk.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class IntegrationPlatformKameletRepositorySpecFluentImpl<A extends IntegrationPlatformKameletRepositorySpecFluent<A>> extends BaseFluent<A> implements IntegrationPlatformKameletRepositorySpecFluent<A>{
  public IntegrationPlatformKameletRepositorySpecFluentImpl() {
  }
  public IntegrationPlatformKameletRepositorySpecFluentImpl(IntegrationPlatformKameletRepositorySpec instance) {
    if (instance != null) {
      this.withUri(instance.getUri());
    }
  }
  private String uri;
  public String getUri() {
    return this.uri;
  }
  public A withUri(String uri) {
    this.uri=uri; return (A) this;
  }
  public Boolean hasUri() {
    return this.uri != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    IntegrationPlatformKameletRepositorySpecFluentImpl that = (IntegrationPlatformKameletRepositorySpecFluentImpl) o;
    if (!java.util.Objects.equals(uri, that.uri)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(uri,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (uri != null) { sb.append("uri:"); sb.append(uri); }
    sb.append("}");
    return sb.toString();
  }
  
}
